@@ -1,13 +1,14 @@
 package App::BencherUtils;
 
-our $DATE = '2016-01-11'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-01-20'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use Log::Any::IfLOG '$log';
 
+use Data::Clean::JSON;
 use Function::Fallback::CoreOrPP qw(clone);
 use Perinci::Sub::Util qw(err);
 use POSIX qw(strftime);
@@ -39,14 +40,26 @@ my %args_common_query = (
     },
 );
 
+sub _clean {
+    state $cleanser = Data::Clean::JSON->get_cleanser;
+    $cleanser->clone_and_clean($_[0]);
+}
+
 sub _json {
     state $json = do {
         require JSON;
-        JSON->new;
+        my $json = JSON->new;
+        $json->convert_blessed(1);
     };
     $json;
 }
 
+sub _encode_json {
+    no strict 'refs';
+    local *version::TO_JSON = sub { "$_[0]" };
+    _json->encode($_[0]);
+}
+
 sub _complete_scenario_module {
     require Complete::Module;
     my %args = @_;
@@ -220,7 +233,8 @@ sub bencher_all {
                 return err("Can't bench", $res) unless $res->[0] == 200;
                 my $filename = "$args{results_dir}/$sn_encoded.$timestamp.json";
                 $log->tracef("Writing file %s ...", $filename);
-                File::Slurper::write_text($filename, _json->encode($res));
+                File::Slurper::write_text($filename,
+                                          _clean(_encode_json($res)));
 
                 $res = Bencher::bencher(
                     action => 'show-scenario',
@@ -245,12 +259,13 @@ sub bencher_all {
                     my $filename = "$args{results_dir}/$sn_encoded.module_startup.".
                         "$timestamp.json",
                         $log->tracef("Writing file %s ...", $filename);
-                    File::Slurper::write_text($filename, _json->encode($res));
+                    File::Slurper::write_text($filename,
+                                              _clean(_encode_json($res)));
                 }
             }; # eval
 
             if ($@) {
-                $log->error("Dies (%s), skipping to the next scenario", $@);
+                $log->errorf("Dies (%s), skipping to the next scenario", $@);
             }
         } # for scenario
     }
@@ -375,6 +390,20 @@ $SPEC{list_bencher_results} = {
             test => 0,
             'x.doc.show_result' => 0,
         },
+        {
+            summary => 'List latest result for each scenario+CPU',
+            src => 'list-bencher-results QUERY --latest',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+        {
+            summary => 'Delete old results',
+            src => 'cd RESULTS_DIR; list-bencher-results --no-latest | xargs rm',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
     ],
 };
 sub list_bencher_results {
@@ -508,7 +537,7 @@ App::BencherUtils - Utilities related to bencher
 
 =head1 VERSION
 
-This document describes version 0.04 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-01-11.
+This document describes version 0.05 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-01-20.
 
 =head1 SYNOPSIS
 
